tensap.approximation package
============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   tensap.approximation.bases
   tensap.approximation.integration
   tensap.approximation.learning
   tensap.approximation.tensor_approximation
   tensap.approximation.tools

Module contents
---------------

.. automodule:: tensap.approximation
   :members:
   :undoc-members:
   :show-inheritance:
